from .client import *
from .utils import *

__title__ = "yarsaw"
__summary__ = "An async wrapper for Random Stuff API"
__author__ = "Bruce"
__version__ = "1.0"

def get_version():
	return __version__
